==> nextcloud-app-mail-5.1.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/sw.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Muhimu",
    "Personal" : "Binafsi",
    "To Do" : "Kufanya",
    "Later" : "Baadaye",
    "Sign in with Google" : "Ingia kwa Google",
    "Save" : "Hifadhi",
    "Name" : "Jina",
    "Password" : "Nenosiri",
    "None" : "Hakuna",
    "Signature" : "Saini",
    "Go back" : "Rudi nyuma",
    "Email address" : "Anwani ya barua pepe",
    "Cancel" : "Cancel",
    "Accounts" : "Akaunti",
    "General" : "Kuu",
    "Layout" : "Mpangilio",
    "List" : "Orodha",
    "Register" : "Sajiri",
    "About" : "Kuhusu",
    "Keyboard shortcuts" : "Mikato ya keyboard",
    "Delete" : "Futa",
    "Search" : "Tafuta",
    "Send" : "Tuma",
    "From" : "Tangu/ kutoka",
    "To" : "Mpaka/ hadi",
    "Choose" : "Chagua",
    "Choose a file to add as attachment" : "Chagua faili kuongeza kama kiambatanisho",
    "Choose a file to share as a link" : "Chagua faili kushirikisha kama kiungo",
    "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} attachments"],
    "Confirm" : "Thibitisha",
    "Later today – {timeLocale}" : "Baadaye leo-{timeLocale}",
    "Tomorrow – {timeLocale}" : "Kesho-{timeLocale}",
    "This weekend – {timeLocale}" : "Wikendi-{timeLocale}",
    "Next week – {timeLocale}" : "Wiki ijayo-{timeLocale}",
    "Favorite" : "Kipendwa",
    "Unread" : "Unread",
    "More actions" : "Vitendo zaidi",
    "Back" : "Rudi",
    "Create event" : "Tengeneza matukio",
    "Create task" : "Tengeneza jukumu",
    "Load more" : "Pakia zaidi",
    "All day" : "Siku yote",
    "Description" : "Maelezo",
    "Create" : "Tengeneza",
    "Comment" : "Maoni",
    "Accept" : "Kubali",
    "Decline" : "Kataa",
    "More options" : "Mibadala zaidi",
    "Remove" : "Ondoa",
    "Other" : "Mengine",
    "Forward" : "Mbele",
    "Translate" : "Tafsiri",
    "Move" : "Hamisha",
    "Loading …" : "Inapakia",
    "{usage} of {limit} used" : "{usage} ya {limit}imetumika",
    "Remove account" : "Ondoa akaunti",
    "Rename" : "Ipe jina jipya",
    "Subscribed" : "Iliyojisajili",
    "Edit message" : "Hariri ujumbe",
    "Reply" : "Jibu",
    "Retry" : "Jaribu tene",
    "Copy to clipboard" : "Nakili kwenye ubao wa kunakili",
    "Add" : "Ongeza",
    "Clear" : "Futa",
    "Close" : "Funga",
    "Date" : "Tarehe",
    "Tags" : "Maoni",
    "Select tags" : "Chagua ukumbusho",
    "Last 7 days" : "Siku 7 zilizopita",
    "Custom" : "Mteja",
    "All" : "Zote",
    "Favorites" : "Vipendwa",
    "Error while sharing file" : "Hitilafu wakati wa kushirikisha faili",
    "Message sent" : "Ujumbe umetumwa",
    "Continue to %s" : "Endelea katika %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-5.1.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/sw.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Muhimu",
    "Personal" : "Binafsi",
    "To Do" : "Kufanya",
    "Later" : "Baadaye",
    "Mail" : "Msururu wa maduka",
    "Sign in with Google" : "Ingia kwa Google",
    "Save" : "Hifadhi",
    "Auto" : "Auto",
    "Name" : "Jina",
    "Password" : "Nenosiri",
    "None" : "Hakuna",
    "Signature" : "Saini",
    "Go back" : "Rudi nyuma",
    "Email address" : "Anwani ya barua pepe",
    "Cancel" : "Cancel",
    "Accounts" : "Akaunti",
    "General" : "Kuu",
    "Layout" : "Mpangilio",
    "List" : "Orodha",
    "Register" : "Sajiri",
    "About" : "Kuhusu",
    "Keyboard shortcuts" : "Mikato ya keyboard",
    "Archive" : "Weka kumbukumbu",
    "Delete" : "Futa",
    "Search" : "Tafuta",
    "Send" : "Tuma",
    "From" : "Tangu/ kutoka",
    "To" : "Mpaka/ hadi",
    "Choose" : "Chagua",
    "Choose a file to add as attachment" : "Chagua faili kuongeza kama kiambatanisho",
    "Choose a file to share as a link" : "Chagua faili kushirikisha kama kiungo",
    "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} attachments"],
    "Confirm" : "Thibitisha",
    "Later today – {timeLocale}" : "Baadaye leo-{timeLocale}",
    "Set reminder for later today" : "Set reminder for later today",
    "Tomorrow – {timeLocale}" : "Kesho-{timeLocale}",
    "Set reminder for tomorrow" : "Set reminder for tomorrow",
    "This weekend – {timeLocale}" : "Wikendi-{timeLocale}",
    "Set reminder for this weekend" : "Set reminder for this weekend",
    "Next week – {timeLocale}" : "Wiki ijayo-{timeLocale}",
    "Set reminder for next week" : "Set reminder for next week",
    "Favorite" : "Kipendwa",
    "Unread" : "Unread",
    "More actions" : "Vitendo zaidi",
    "Back" : "Rudi",
    "Create event" : "Tengeneza matukio",
    "Create task" : "Tengeneza jukumu",
    "Load more" : "Pakia zaidi",
    "All day" : "Siku yote",
    "Description" : "Maelezo",
    "Create" : "Tengeneza",
    "Select" : "Chagua",
    "Comment" : "Maoni",
    "Accept" : "Kubali",
    "Decline" : "Kataa",
    "More options" : "Mibadala zaidi",
    "Remove" : "Ondoa",
    "Other" : "Mengine",
    "Forward" : "Mbele",
    "Translate" : "Tafsiri",
    "Move" : "Hamisha",
    "Loading …" : "Inapakia",
    "{usage} of {limit} used" : "{usage} ya {limit}imetumika",
    "Remove account" : "Ondoa akaunti",
    "Rename" : "Ipe jina jipya",
    "Subscribed" : "Iliyojisajili",
    "Edit message" : "Hariri ujumbe",
    "Reply" : "Jibu",
    "Retry" : "Jaribu tene",
    "Copy to clipboard" : "Nakili kwenye ubao wa kunakili",
    "Add" : "Ongeza",
    "Clear" : "Futa",
    "Close" : "Funga",
    "Date" : "Tarehe",
    "Tags" : "Maoni",
    "Select tags" : "Chagua ukumbusho",
    "Last 7 days" : "Siku 7 zilizopita",
    "Custom" : "Mteja",
    "Not found" : "Haipatikani",
    "Mark as unread" : "Weka alama kama haijasomwa",
    "Mark as read" : "Weka alama kama iliyosomwa",
    "Copy translated text" : "Nakili maandishi yaliyotafsiriwa",
    "Untitled event" : "Tukio lisilotajwa",
    "(organizer)" : "(Mratibu)",
    "Priority" : "Kipaumbele",
    "Reset" : "Pangilia upya",
    "Client ID" : "Kitambulisho cha mteja",
    "Client secret" : "Siri ya mteja",
    "User" : "Mtumiaji",
    "Host" : "Host",
    "Port" : "Port",
    "Valid until" : "Halali mpaka",
    "Certificate" : "Cheti",
    "Submit" : "Wasilisha",
    "Account connected" : "Akaunti imeunganishwa",
    "All" : "Zote",
    "Favorites" : "Vipendwa",
    "Error while sharing file" : "Hitilafu wakati wa kushirikisha faili",
    "Message sent" : "Ujumbe umetumwa",
    "Redirect" : "Elekeza upya",
    "Continue to %s" : "Endelea katika %s",
    "Actions" : "Matendo",
    "New action" : "Kitendo kipya"
},
"nplurals=2; plural=(n != 1);");
